"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const matchingContentSourceAdapter_1 = require("./matchingContentSourceAdapter");
const bundleSourceAdapter_1 = require("./bundleSourceAdapter");
const mixedContentSourceAdapter_1 = require("./mixedContentSourceAdapter");
const errors_1 = require("../../errors");
const decomposedSourceAdapter_1 = require("./decomposedSourceAdapter");
const defaultSourceAdapter_1 = require("./defaultSourceAdapter");
var AdapterId;
(function (AdapterId) {
    AdapterId["Bundle"] = "bundle";
    AdapterId["Decomposed"] = "decomposed";
    AdapterId["MatchingContentFile"] = "matchingContentFile";
    AdapterId["MixedContent"] = "mixedContent";
})(AdapterId = exports.AdapterId || (exports.AdapterId = {}));
exports.getAdapter = (type, adapterId, forceIgnore) => {
    switch (adapterId) {
        case AdapterId.Bundle:
            return new bundleSourceAdapter_1.BundleSourceAdapter(type, undefined, forceIgnore);
        case AdapterId.Decomposed:
            return new decomposedSourceAdapter_1.DecomposedSourceAdapter(type, undefined, forceIgnore);
        case AdapterId.MatchingContentFile:
            return new matchingContentSourceAdapter_1.MatchingContentSourceAdapter(type, undefined, forceIgnore);
        case AdapterId.MixedContent:
            return new mixedContentSourceAdapter_1.MixedContentSourceAdapter(type, undefined, forceIgnore);
        case undefined:
            return new defaultSourceAdapter_1.DefaultSourceAdapter(type, undefined, forceIgnore);
        default:
            throw new errors_1.RegistryError('error_missing_adapter', [type.name, adapterId]);
    }
};
//# sourceMappingURL=index.js.map